==> request-tracker4_4.4.7+dfsg.orig-third-party-source.tar.gz: rt-4.4.7/devel/third-party/ckeditor-src/plugins/link/lang/pt-br.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'pt-br', {
	acccessKey: 'Chave de Acesso',
	advanced: 'Avançado',
	advisoryContentType: 'Tipo de Conteúdo',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: 'Inserir/Editar Âncora',
		menu: 'Formatar Âncora',
		title: 'Formatar Âncora',
		name: 'Nome da Âncora',
		errorName: 'Por favor, digite o nome da âncora',
		remove: 'Remover Âncora'
	},
	anchorId: 'Id da âncora',
	anchorName: 'Nome da âncora',
	charset: 'Charset do Link',
	cssClasses: 'Classe de CSS',
	emailAddress: 'Endereço E-Mail',
	emailBody: 'Corpo da Mensagem',
	emailSubject: 'Assunto da Mensagem',
	id: 'Id',
	info: 'Informações',
	langCode: 'Direção do idioma',
	langDir: 'Direção do idioma',
	langDirLTR: 'Esquerda para Direita (LTR)',
	langDirRTL: 'Direita para Esquerda (RTL)',
	menu: 'Editar Link',
	name: 'Nome',
	noAnchors: '(Não há âncoras no documento)',
	noEmail: 'Por favor, digite o endereço de e-mail',
	noUrl: 'Por favor, digite o endereço do Link',
	other: '<outro>',
	popupDependent: 'Dependente (Netscape)',
	popupFeatures: 'Propriedades da Janela Pop-up',
	popupFullScreen: 'Modo Tela Cheia (IE)',
	popupLeft: 'Esquerda',
	popupLocationBar: 'Barra de Endereços',
	popupMenuBar: 'Barra de Menus',
	popupResizable: 'Redimensionável',
	popupScrollBars: 'Barras de Rolagem',
	popupStatusBar: 'Barra de Status',
	popupToolbar: 'Barra de Ferramentas',
	popupTop: 'Topo',
	rel: 'Tipo de Relação',
	selectAnchor: 'Selecione uma âncora',
	styles: 'Estilos',
	tabIndex: 'Índice de Tabulação',
	target: 'Destino',
	targetFrame: '<frame>',
	targetFrameName: 'Nome do Frame de Destino',
	targetPopup: '<janela popup>',
	targetPopupName: 'Nome da Janela Pop-up',
	title: 'Editar Link',
	toAnchor: 'Âncora nesta página',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'Inserir/Editar Link',
	type: 'Tipo de hiperlink',
	unlink: 'Remover Link',
	upload: 'Enviar ao Servidor'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/link/lang/pt-br.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'pt-br', {
	acccessKey: 'Chave de Acesso',
	advanced: 'Avançado',
	advisoryContentType: 'Tipo de Conteúdo',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: 'Inserir/Editar Âncora',
		menu: 'Formatar Âncora',
		title: 'Formatar Âncora',
		name: 'Nome da Âncora',
		errorName: 'Por favor, digite o nome da âncora',
		remove: 'Remover Âncora'
	},
	anchorId: 'Id da âncora',
	anchorName: 'Nome da âncora',
	charset: 'Charset do Link',
	cssClasses: 'Classe de CSS',
	download: 'Forçar Download',
	displayText: 'Exibir Texto',
	emailAddress: 'Endereço E-Mail',
	emailBody: 'Corpo da Mensagem',
	emailSubject: 'Assunto da Mensagem',
	id: 'Id',
	info: 'Informações',
	langCode: 'Direção do idioma',
	langDir: 'Direção do idioma',
	langDirLTR: 'Esquerda para Direita (LTR)',
	langDirRTL: 'Direita para Esquerda (RTL)',
	menu: 'Editar Link',
	name: 'Nome',
	noAnchors: '(Não há âncoras no documento)',
	noEmail: 'Por favor, digite o endereço de e-mail',
	noUrl: 'Por favor, digite o endereço do Link',
	noTel: 'Please type the phone number', // MISSING
	other: '<outro>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependente (Netscape)',
	popupFeatures: 'Propriedades da Janela Pop-up',
	popupFullScreen: 'Modo Tela Cheia (IE)',
	popupLeft: 'Esquerda',
	popupLocationBar: 'Barra de Endereços',
	popupMenuBar: 'Barra de Menus',
	popupResizable: 'Redimensionável',
	popupScrollBars: 'Barras de Rolagem',
	popupStatusBar: 'Barra de Status',
	popupToolbar: 'Barra de Ferramentas',
	popupTop: 'Topo',
	rel: 'Tipo de Relação',
	selectAnchor: 'Selecione uma âncora',
	styles: 'Estilos',
	tabIndex: 'Índice de Tabulação',
	target: 'Destino',
	targetFrame: '<frame>',
	targetFrameName: 'Nome do Frame de Destino',
	targetPopup: '<janela popup>',
	targetPopupName: 'Nome da Janela Pop-up',
	title: 'Editar Link',
	toAnchor: 'Âncora nesta página',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Inserir/Editar Link',
	type: 'Tipo de hiperlink',
	unlink: 'Remover Link',
	upload: 'Enviar ao Servidor'
} );
